@@ -1,4 +1,4 @@
-from typing import List, Optional, Union
+from typing import Dict, Iterable, Optional, Union
 
 from crowdin_api.api_resources.abstract.resources import BaseResource
 from crowdin_api.api_resources.projects.enums import (
@@ -17,11 +17,16 @@ class ProjectsResource(BaseResource):
     Using projects, you can keep your source files sorted.
     Use API to manage projects, change their settings, or remove them if required.
 
-    Link to documentation: https://support.crowdin.com/api/v2/#tag/Projects
+    Link to documentation:
+    https://support.crowdin.com/api/v2/#tag/Projects
 
     """
 
-    base_path = "projects"
+    def get_projects_path(self, projectId: Optional[int] = None):
+        if projectId is not None:
+            return f"projects/{projectId}"
+
+        return "projects"
 
     def list_projects(
         self,
@@ -29,32 +34,43 @@ class ProjectsResource(BaseResource):
         offset: Optional[int] = None,
         limit: Optional[int] = None,
         userId: Optional[Union[int, str]] = None,
-        hasManagerAccess: HasManagerAccess = HasManagerAccess.FALSE,
+        hasManagerAccess: Optional[HasManagerAccess] = None,
     ):
         """
         List Projects.
 
-        Link to documentation: https://support.crowdin.com/api/v2/#operation/api.projects.getMany
+        Link to documentation:
+        https://support.crowdin.com/api/v2/#operation/api.projects.getMany
         """
 
         params = {"userId": userId, "hasManagerAccess": hasManagerAccess}
         params.update(self.get_page_params(page=page, offset=offset, limit=limit))
 
+        return self.requester.request(method="get", path=self.get_projects_path(), params=params)
+
+    def add_project(self, request_data: Dict):
+        """
+        Add Project.
+
+        Link to documentation:
+        https://support.crowdin.com/api/v2/#operation/api.projects.post
+        """
+
         return self.requester.request(
-            method="get", path=self.prepare_path(), params=params
+            method="post", path=self.get_projects_path(), request_data=request_data
         )
 
-    def add_project(
+    def add_file_based_project(
         self,
         name: str,
         sourceLanguageId: str,
-        identifier: Optional[str] = None,
-        type: ProjectType = ProjectType.FILE_BASED,
+        type: Optional[ProjectType] = None,
         normalizePlaceholder: Optional[bool] = None,
         saveMetaInfoInSource: Optional[bool] = None,
-        targetLanguageIds: Optional[List[str]] = None,
-        visibility: ProjectVisibility = ProjectVisibility.PRIVATE,
-        languageAccessPolicy: ProjectLanguageAccessPolicy = ProjectLanguageAccessPolicy.OPEN,
+        identifier: Optional[str] = None,
+        targetLanguageIds: Optional[Iterable[str]] = None,
+        visibility: Optional[ProjectVisibility] = None,
+        languageAccessPolicy: Optional[ProjectLanguageAccessPolicy] = None,
         cname: Optional[str] = None,
         description: Optional[str] = None,
         skipUntranslatedStrings: Optional[bool] = None,
@@ -62,15 +78,14 @@ class ProjectsResource(BaseResource):
         exportApprovedOnly: Optional[bool] = None,
     ):
         """
-        Add Project.
+        Add Project(Files Based Project Form).
 
-        Link to documentation: https://support.crowdin.com/api/v2/#operation/api.projects.post
+        Link to documentation:
+        https://support.crowdin.com/api/v2/#operation/api.projects.post
         """
 
-        return self.requester.request(
-            method="post",
-            path=self.prepare_path(),
-            post_data={
+        return self.add_project(
+            request_data={
                 "name": name,
                 "sourceLanguageId": sourceLanguageId,
                 "identifier": identifier,
@@ -88,34 +103,78 @@ class ProjectsResource(BaseResource):
             },
         )
 
-    def get_project(self, projectId):
+    def add_strings_based_project(
+        self,
+        name: str,
+        sourceLanguageId: str,
+        identifier: Optional[str] = None,
+        type: Optional[ProjectType] = None,
+        targetLanguageIds: Optional[Iterable[str]] = None,
+        visibility: Optional[ProjectVisibility] = None,
+        languageAccessPolicy: Optional[ProjectLanguageAccessPolicy] = None,
+        cname: Optional[str] = None,
+        description: Optional[str] = None,
+        skipUntranslatedStrings: Optional[bool] = None,
+        skipUntranslatedFiles: Optional[bool] = None,
+        exportApprovedOnly: Optional[bool] = None,
+    ):
+        """
+        Add Project(Strings Based Project Form).
+
+        Link to documentation:
+        https://support.crowdin.com/api/v2/#operation/api.projects.post
+        """
+
+        return self.add_project(
+            request_data={
+                "name": name,
+                "sourceLanguageId": sourceLanguageId,
+                "identifier": identifier,
+                "type": type,
+                "targetLanguageIds": targetLanguageIds,
+                "visibility": visibility,
+                "languageAccessPolicy": languageAccessPolicy,
+                "cname": cname,
+                "description": description,
+                "skipUntranslatedStrings": skipUntranslatedStrings,
+                "skipUntranslatedFiles": skipUntranslatedFiles,
+                "exportApprovedOnly": exportApprovedOnly,
+            },
+        )
+
+    def get_project(self, projectId: int):
         """
         Get Project.
 
-        Link to documentation: https://support.crowdin.com/api/v2/#operation/api.projects.get
+        Link to documentation:
+        https://support.crowdin.com/api/v2/#operation/api.projects.get
         """
 
-        return self.requester.request(method="get", path=self.prepare_path(projectId))
+        return self.requester.request(
+            method="get", path=self.get_projects_path(projectId=projectId)
+        )
 
-    def delete_project(self, projectId):
+    def delete_project(self, projectId: int):
         """
         Delete Project.
 
-        Link to documentation: https://support.crowdin.com/api/v2/#operation/api.projects.delete
+        Link to documentation:
+        https://support.crowdin.com/api/v2/#operation/api.projects.delete
         """
 
         return self.requester.request(
-            method="delete", path=self.prepare_path(projectId)
+            method="delete", path=self.get_projects_path(projectId=projectId)
         )
 
-    def edit_project(self, projectId, data: List[ProjectPatchRequest]):
+    def edit_project(self, projectId: int, data: Iterable[ProjectPatchRequest]):
         """
         Edit Project.
 
-        Link to documentation: https://support.crowdin.com/api/v2/#operation/api.projects.patch
+        Link to documentation:
+        https://support.crowdin.com/api/v2/#operation/api.projects.patch
         """
         return self.requester.request(
             method="patch",
-            path=self.prepare_path(projectId),
-            post_data=data,
+            path=self.get_projects_path(projectId=projectId),
+            request_data=data,
         )
